@@ -4,11 +4,11 @@ use warnings;
 use strict;
 
 use vars qw($VERSION $AUTOLOAD @ISA @EXPORT);
-$VERSION = '5.12';
+$VERSION = '5.13';
 
 =head1 NAME
 
-Labyrinth::Constraints
+Labyrinth::Constraints - Basic Constraint Handler for Labyrinth
 
 =head1 DESCRIPTION
 
@@ -111,7 +111,7 @@ sub url {
 sub match_url {
     my ($self,$text) = @_;
     $text =~ /^($settings{urlregex})$/x;
-    return undef                unless($1);
+    return                      unless($1);
     $text = 'http://' . $text   unless($2);
     return $text;
 }
@@ -147,7 +147,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2011 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2012 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
