@@ -4,11 +4,11 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.12';
+$VERSION = '5.13';
 
 =head1 NAME
 
-Labyrinth::Groups - Manage user groups in Labyrinth
+Labyrinth::Groups - User Group Manager for Labyrinth
 
 =head1 DESCRIPTION
 
@@ -75,7 +75,7 @@ number of rows you require.
 sub GetGroupID {
     my $name = shift;
     my @rows = $dbi->GetQuery('array','GetGroupID',$name);
-    return undef    unless(@rows);
+    return  unless(@rows);
     return $rows[0]->[0];
 }
 
@@ -124,7 +124,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2011 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2012 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
