@@ -5,11 +5,11 @@ use strict;
 use utf8;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.12';
+$VERSION = '5.13';
 
 =head1 NAME
 
-Labyrinth::Mailer - Set of general Mailer Functions.
+Labyrinth::Mailer - Mail Manager for Labyrinth 
 
 =head1 SYNOPSIS
 
@@ -110,15 +110,11 @@ sub MailSend {
     }
 
     if($hash{output}) {
-        open(FH, ">>:utf8", $hash{output})    or die "Cannot write to file [$hash{output}]: $!";
-        print FH $body;
-        print FH "\n\n#-----\n";
-#        my $fh = IO::File->new($hash{output},'a+')    or die "Cannot write to file [$hash{output}]: $!";
-#        binmode($fh,':utf8');
-#        print $fh $body;
-#        print $fh "\n\n#-----\n";
-#        $fh->close;
-        close(FH);
+        my $fh = IO::File->new($hash{output},'a+')  or die "Cannot write to file [$hash{output}]: $!";
+        $fh->binmode(':utf8');
+        print $fh $body;
+        print $fh "\n\n#-----\n";
+        $fh->close;
         $mailer{result} = 1;
         $tvars{mailer}{result} = 1;
     } else {
@@ -126,7 +122,7 @@ sub MailSend {
         my $cmd = qq!| $mailer{mailsend} $email!;
 
         if(my $fh = IO::File->new($cmd)) {
-#            binmode($fh,':utf8');
+            $fh->binmode(':utf8');
             print $fh $body;
             $fh->close;
             $mailer{result} = 1;
@@ -272,7 +268,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2011 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2012 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
